::: jaxscape.graph.AbstractGraph
    options:
      members: get_adjacency_matrix

::: jaxscape.graph.Graph
    options:
      members:
        - get_adjacency_matrix
::: jaxscape.graph.GridGraph
    options:
      members: 
        - coord_to_index
        - index_to_coord
        - node_values_to_array
        - array_to_node_values
